"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.echo = exports.cmd = void 0;
const commandLine = require("../../command-line");
const debug_1 = require("../../debug");
const types_1 = require("../types");
const command_1 = require("./command");

/** `run()` method for `LineCommand`. */
const runUnit = function (onEvent) {
  const { line, name } = this;
  debug_1.traceRun(name);
  onEvent(this, types_1.Event.Start);
  return commandLine.execLineWithoutLog(line).then(
    () => {
      debug_1.traceDone(name);
      onEvent(this, types_1.Event.Success);
    },
    (reason) => {
      onEvent(this, types_1.Event.Failure);
      return Promise.reject(reason);
    }
  );
};

/** Creates a `Command` unit. */
const cmd = (command, ...args) => {
  const line = commandLine.create(command, args);
  const base = command_1.createCommand({
    name: line,
    run: runUnit,
    type: types_1.CommandType.Unit,
    subType: types_1.CommandSubType.CommandLine,
  });
  return Object.assign(base, { line });
};
exports.cmd = cmd;

/** Creates an `echo` command (does not be run immediately). */
const echo = (s) => exports.cmd("echo", s);
exports.echo = echo;
