"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const log_1 = require("../../log");
const config_1 = require("../../config");
const types_1 = require("../types");
const traverse_1 = require("../tools/traverse");
const record_1 = require("./record");
const result_summary_1 = require("./result-summary");

/**
 * Runs any `command` in a `try-catch` block.
 */
const run = async (command, onEvent, onSuccessAll, onFailureAny) => {
  const numTotal = traverse_1.countUnitCommands(command);
  let numComplete = 0;
  const recorder = record_1.createRecorder();
  const recordEvent = (command, event) => {
    recorder.record(command, event);
    if (
      command.type === types_1.CommandType.Unit &&
      event === types_1.Event.Success
    )
      log_1.log(`done ${(numComplete += 1)} / ${numTotal}`);
  };
  const eventHandler = onEvent
    ? (command, event) => {
        recordEvent(command, event);
        onEvent(command, event);
      }
    : recordEvent;
  try {
    await command.run(eventHandler);
    if (onSuccessAll) onSuccessAll();
  } catch (e) {
    log_1.error(e);
    if (onFailureAny) onFailureAny();
  }
  if (config_1.resultSummaryType) {
    log_1.newLine();
    result_summary_1.renderResultSummary(command, recorder);
    log_1.newLine();
  }
  return recorder.historyMap;
};
exports.run = run;
