"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.countUnitCommands = exports.depthFirstSearch = void 0;
const types_1 = require("../types");

/**
 * Runs `callback` for `topCommand` and all of its descendants
 * in a depth-first order.
 */
const depthFirstSearch = (topCommand, callback, currentDepth = 0) => {
  callback(topCommand, currentDepth);
  if (!topCommand.children) return;
  const childDepth = currentDepth + 1;
  for (const child of topCommand.children)
    exports.depthFirstSearch(child, callback, childDepth);
};
exports.depthFirstSearch = depthFirstSearch;

/** Count all descendant unit commands beginning from `topCommand`. */
const countUnitCommands = (topCommand) => {
  let numCommands = 0;
  exports.depthFirstSearch(topCommand, (command) => {
    if (command.type === types_1.CommandType.Unit) numCommands += 1;
  });
  return numCommands;
};
exports.countUnitCommands = countUnitCommands;
