/** Value that specifies the type of a `Command` object. */
export declare const CommandType: {
  readonly Unit: "unit";
  readonly Group: "group";
};
export declare type CommandType = typeof CommandType[keyof typeof CommandType];
/** Value that specifies the sub-type of a `Command` object. */
export declare const CommandSubType: {
  readonly CommandLine: "commandline";
  readonly External: "external";
  readonly Null: "null";
  readonly Sequence: "sequence";
  readonly Parallel: "parallel";
};
export declare type CommandSubType = typeof CommandSubType[keyof typeof CommandSubType];
/** Event fired by `Command` objects. */
export declare const Event: {
  readonly Start: "start";
  readonly Success: "success";
  readonly Failure: "failure";
};
export declare type Event = typeof Event[keyof typeof Event];
/** Function for hadnling command events. */
export declare type EventHandler = (command: Command, event: Event) => void;
/** Command object. Can be wrapped with `seq()` or `par()`. */
export interface Command {
  readonly run: (onEvent: EventHandler) => Promise<void>;
  readonly type: CommandType;
  readonly subType: CommandSubType;
  readonly children?: Command[];
  readonly rename: (name: string) => Command;
  name: string;
}
/** Data unit for recording fired events. */
export interface EventRecord {
  event: Event;
  timestamp: number;
}
/** Return value from `run()`. */
export declare type Result = Map<Command, EventRecord[]>;
/** Object that runs different commands depending on the given key. */
export interface Router {
  readonly run: (
    key: string,
    onEvent?: (command: Command, event: Event) => any,
    onSuccessAll?: () => any,
    onFailureAny?: () => any
  ) => Promise<Result>;
  readonly help: () => void;
}
